TrustStore

Struct TrustStore 

pub struct TrustStore { /* private fields */ }
The trust store — manages all known peer records

Implementations

Source

impl TrustStore

pub fn new() -> Self

Create a new empty trust store

pub async fn verify_or_pin( &self, peer_id: &str, public_key: &[u8], ) -> TrustResult<bool>

Called when we first encounter a peer’s public key (TOFU).

Returns Ok(true) if this is a new peer, Ok(false) if key matches. Returns Err if key has changed for a known peer.

pub async fn add_attestation(&self, attestation: Attestation) -> TrustResult<()>

Record an attestation from a trusted peer about another peer

pub async fn mark_verified( &self, peer_id: &str, verified_key: &[u8], ) -> TrustResult<()>

Upgrade a peer to Verified status (after out-of-band verification)

pub async fn block(&self, peer_id: &str)

Block a peer

pub async fn get(&self, peer_id: &str) -> Option<PeerRecord>

Get trust info for a peer

pub async fn trust_score(&self, peer_id: &str) -> f32

Get trust score (0.0–1.0, or negative for warnings)

pub async fn all_peers(&self) -> Vec<PeerRecord>

List all known peers, sorted by trust score descending

pub async fn set_attester_trust(&self, peer_id: String, score: f32)

Set our trust score for a peer

pub async fn blocked_count(&self) -> usize

Count of blocked peers

pub async fn average_trust_score(&self) -> f32

Average trust score across all known peers